##  Overview
The LeanIX receiver adapter connects SAP Integration Suite to SAP LeanIX and allows data exchange between the two systems. The adapter reads data from SAP LeanIX workspaces for further processing in SAP Integration Suite.
SAP Integration Suite is an integration platform-as-a-service (iPaaS) that enables businesses to seamlessly connect and integrate applications, data, and processes both internally and externally. For more information, see [SAP Integration Suite](https://help.sap.com/docs/integration-suite "https://help.sap.com/docs/integration-suite").
